#
# spec file for package pprof
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pprof
Version:        0.0.0+git20230820.407c9e7
Release:        1.6
Summary:        CLI tool for visualization and analysis of profiling data
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://github.com/google/pprof
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.14

%description
pprof reads a collection of profiling samples in profile.proto format and generates reports to visualize and help analyze the data.
It can generate both text and graphical reports (through the use of the dot visualization package).

%prep
%autosetup -a1

%build
go build

%install
install -Dm0755 %{name} %{buildroot}%{_bindir}/%{name}

%files
%doc README.md CONTRIBUTORS CONTRIBUTING.md AUTHORS
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Aug 21 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.0.0+git20230820.407c9e7:
  * Bump actions/setup-go from 4.0.1 to 4.1.0 (#795)
  * Introduce first test for browser-side behavior. (#798)
  * Remove GOPATH based workflows since Go is reducing support. (#799)
  * Fix flamegraph name matching. (#796)
  * Expanded documentation of pprof web interface. (#793)
  * Prefix sample type menu entry ids with "sampletype-". (#792)
  * Fix flamegraph display in the presence of --diff_base. (#790)
  * Hash-pin workflow Actions (#787)
  * Fix away a few tab characters in *.js files added recently by accident. (#785)
  * Start using the new demangle.NoEnclosingParams demangling option. (#784)
  * Make comment to locations field a bit clearer. (#770)
  * Made non-D3 flamegraph view the default. (#777) (#781)
  * Remove special coloring for self region in new flame graph view. (#782)
  * Add more clear err message upon disasm addr/regex (#776)
  * Fix code coverage. (#778)
  * fix some comments (#779)
  * Update macOs matrix since macos-10.15 is deprecated and unavailable. (#780)
  * internal/driver: fixes for fetch.go (#711)
  * Remove the heuristic of recognizing build ID command line arg. (#775)
  * Increase linter timeout since it times out sometimes. (#774)
  * Get rid of strings.ReplaceAll to save an alloc (#772)
  * typo: 'browswer' -> 'browser' (#762)
  * Update Ubuntu versions as 18.04 is not supported now. (#764)
  * chore(ci): Upgrade to non-deprecated runtimes (#759)
  * fix typo: ocurrences -> occurrences (#758)
  * Bump golang.org/x/sys from 0.0.0-20220310020820-b874c991c1a5 to 0.1.0 (#756)
  * go.mod: update dependencies (#745)
  * Extend search for debug symbols (#741)
  * Update Go version reqs as 1.20 is released now. (#751)
  * NumLabel helper functions for Profile. (#749)
  * Add a bit more docs on label value handling. (#750)
  * Clarify that the comment field should only be used for human-readable content. (#746)
  * Modify the name shortening heuristic to handle non-Go names (#743)
  * Do not overwrite main binary build ID when it's present. (#742)
  * Update codecov action version. (#737)
  * Fix use of captured loop variable in go routine. (#740)
  * Apply -noinlines flag to the proto output. (#739)
  * Compatibilize profiles before merging (#734)
  * Disable golangci-lint on tip (#735)
  * Start using golangci-lint instead of the deprecated x/lint. (#731)
  * Speed-up profile management. (#729)
  * Increase chunk size for concurrent fetch to 128 (#727)
  * Add new symbol directory layout by build-id `/xx/xxxxxxxx.debug`. (#724)
  * Add visual indication of inlined frames. (#723)
  * Go 1.19 released, so update supported Go versions. (#721)
  * Update pprof documentation on tags. (#722)
  * Added alternative flamegraph implementation that can show callers. (#716)
  * Improve handling of Go symbols with type parameters (#717)
  * chore: run integration tests against main branch (#682)
* Sun Jul 10 2022 gmbr3@opensuse.org
- Update to version 0.0.0+git20220520.d04f242:
  * Make config menu entries relative.
  * Made flamegraph test less brittle.
  * all: update dependencies
  * Generalize the unit support in pprof a bit further.
  * Split monolithic webhtml.go into multiple files.
  * Update minimum Go version to 1.17 in go.mod.
  * Fix doc comments format to become compatible with tip gofmt.
  * allow rendering big flame graphs by avoiding stack overflow in JS parser
  * Fix tagroot to properly format unitless numeric tags.
  * Add Go 1.18 to testing, remove Go 1.16.
  * third_party: fix typo
  * internal/graph: Support comments with double quotes
  * Handle either _text or _stext as the kernel relocation symbol.
  * Parse and propagate the name of the kernel relocation symbol
  * doc: clarify graph view docs to note negative values appear in profile comparison
  * internal/elfexec: Fix typos in elfexec.go
  * Log build ID in local symbolization error messages.
  * Update d3-flame-graph from 2.0.0-alpha to 4.1.3
  * Add badge link to Go API docs in pkg.go.dev
  * Update instructions to use "git clone" instead of "go get".
  * proto/profile.proto: fix typo
  * Update mapassign regex to match both call variants
* Tue Mar 23 2021 Callum Farmer <gmbr3@opensuse.org>
- Use single %%doc
- Don't use if for %%license
- Don't %%check there are no tests
* Tue Mar 23 2021 Jan Engelhardt <jengelh@inai.de>
- Fix double %%setup.
* Thu Mar 18 2021 gmbr3@opensuse.org
- Initial packaging 0.0.20210226
